Struct Apn
#[repr(transparent)]
pub struct Apn(ApnInfo);
Creates a new APN configuration with default values.
The default values are the same as Builder::new().build() would
produce.
See the builder methods for more details on the default values.
Returns the profile index associated with this APN configuration.
Returns a new builder for constructing an APN configuration.
Performs copy-assignment from
source.
Read more
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Instruments this type with the provided [
Span], returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.